@@ -2,6 +2,7 @@
 
 import os
 import sys
+import ast
 from argparse import ArgumentParser
 import onnx
 import onnx_graphsurgeon as gs
@@ -507,7 +508,7 @@ def main():
     """
     input_variables_tmp = None
     if args.add_op_input_variables:
-        input_variables_tmp = {input_variable[0]: [getattr(np, input_variable[1]), eval(input_variable[2])] for input_variable in args.add_op_input_variables}
+        input_variables_tmp = {input_variable[0]: [getattr(np, input_variable[1]), ast.literal_eval(input_variable[2])] for input_variable in args.add_op_input_variables}
 
     # add op output variables
     """
@@ -515,7 +516,7 @@ def main():
     """
     output_variables_tmp = None
     if args.add_op_output_variables:
-        output_variables_tmp = {output_variable[0]: [getattr(np, output_variable[1]), eval(output_variable[2])] for output_variable in args.add_op_output_variables}
+        output_variables_tmp = {output_variable[0]: [getattr(np, output_variable[1]), ast.literal_eval(output_variable[2])] for output_variable in args.add_op_output_variables}
 
     # add op attributes
     """
@@ -537,7 +538,7 @@ def main():
             # parse
             attr_name = attribute[0]
             attr_type = attribute[1]
-            attr_value = eval(attribute[2])
+            attr_value = ast.literal_eval(attribute[2])
 
             # dtype check
             if attr_type not in AVAILABLE_DTYPES:
